@@ -14,29 +14,46 @@ from klein import resource, route
 from twisted.python import log
 from twisted.web.static import File
 
+from cidr import get_IP_list
+
 # Shut up the linter.
 resource
 
 CONFIGURATION = {
-    'allowed_ips': [
-        '127.0.0.1',
-        '54.235.183.49',
-        '54.235.183.23',
-        '54.235.118.251',
-        '54.235.120.57',
-        '54.235.120.61',
-        '54.235.120.62',
-        '207.97.227.253',
-        '50.57.128.197',
-        '50.57.231.61',
-        '108.171.174.178',
+    # Update it from https://api.github.com/meta
+    'allow_cidr': [
+        '127.0.0.1/24',
+        "207.97.227.253/32",
+        "50.57.128.197/32",
+        "108.171.174.178/32",
+        "50.57.231.61/32",
+        "204.232.175.64/27",
+        "192.30.252.0/22",
         ],
+    # Cached list of allowed IP address.
+    # Expanded at startup based on CIDR.
+    # call `expand_allowed_ips()` if `allow_cidr` is changed at runtime.
+    '_allowed_ips': {},
     'callback': None,
 }
 
 STATIC_PATH = os.path.join(os.path.dirname(__file__), 'static')
 
 
+def expand_allowed_ips():
+    """
+    Expand the cached list of allowed ips.
+    """
+    CONFIGURATION['_allowed_ips'] = {}
+
+    for block in CONFIGURATION['allow_cidr']:
+        for ip in get_IP_list(block):
+            CONFIGURATION['_allowed_ips'][ip] = True
+
+# Do initial expansion.
+expand_allowed_ips()
+
+
 class Event(object):
     """
     Simple container for GitHub Event.
@@ -98,7 +115,7 @@ def hook(request, hook_name):
     Check that request is valid, parse the content and then pass
     the object for further processing.
     """
-    if not request.getClientIP() in CONFIGURATION['allowed_ips']:
+    if request.getClientIP() not in CONFIGURATION['_allowed_ips']:
         request.code = 403
         log.msg(
             'Receive request for hook "%(name)s" from unauthorized'
