@@ -20,7 +20,7 @@ from twisted.internet.address import IPv4Address
 from twisted.trial.unittest import TestCase
 from twisted.web.test.test_web import DummyRequest
 
-from txghserf.server import CONFIGURATION, hook
+from txghserf.server import CONFIGURATION, expand_allowed_ips, hook
 
 
 class TestServer(TestCase):
@@ -30,26 +30,48 @@ class TestServer(TestCase):
 
     def setUp(self):
         super(TestServer, self).setUp()
-        self._allowed_ips = CONFIGURATION['allowed_ips'][:]
+        self._allow_cidr = CONFIGURATION['allow_cidr'][:]
         self._callback = CONFIGURATION['callback']
 
         self.request = DummyRequest([])
         ip = '10.0.0.100'
-        CONFIGURATION['allowed_ips'].append(ip)
+        CONFIGURATION['allow_cidr'] = ['10.0.0.0/24']
+        expand_allowed_ips()
         self.request.client = IPv4Address('TCP', ip, 2345)
 
     def tearDown(self):
-        CONFIGURATION['allowed_ips'] = self._allowed_ips
+        CONFIGURATION['allow_cidr'] = self._allow_cidr
+        expand_allowed_ips()
         CONFIGURATION['callback'] = self._callback
         super(TestServer, self).tearDown()
 
+    def test_allow_cidr_change_runtime(self):
+        """
+        When allow_cidr is changed at runtime, `expand_allowed_ips` must
+        be called to update the cache.
+        """
+        CONFIGURATION['allow_cidr'] = [
+            '192.30.252.0/22',
+            '108.171.174.178/32',
+            ]
+        expand_allowed_ips()
+
+        self.assertFalse('192.30.251.255' in CONFIGURATION['_allowed_ips'])
+        self.assertTrue('192.30.252.0' in CONFIGURATION['_allowed_ips'])
+        self.assertTrue('192.30.254.34' in CONFIGURATION['_allowed_ips'])
+        self.assertTrue('192.30.255.255' in CONFIGURATION['_allowed_ips'])
+        self.assertFalse('192.30.256.0' in CONFIGURATION['_allowed_ips'])
+
+        self.assertFalse('108.171.174.177' in CONFIGURATION['_allowed_ips'])
+        self.assertTrue('108.171.174.178' in CONFIGURATION['_allowed_ips'])
+        self.assertFalse('108.171.174.179' in CONFIGURATION['_allowed_ips'])
+
     def test_hook_bad_ip(self):
         """
         An error is raised when request is comming from an untrusted IP.
         """
         request = DummyRequest([])
-        request.client = IPv4Address('TCP', '10.0.0.0', 2345)
-
+        request.client = IPv4Address('TCP', '111.0.0.0', 2345)
         result = hook(request, 'hook_name')
 
         self.assertEqual(403, request.code)
